@@ -39,13 +39,14 @@ final class GlueIOIOPort extends IOIOPort implements IOIOConnectionListener {
   private static final String TAG = "XCSoar";
 
   private IOIOConnectionHolder holder;
-  private boolean connected;
 
   /**
-   * Set to true when the connection is being cycled, e.g. during a
-   * baud rate change.  It is used by waitCycled().
+   * Is the #IOIOConnectionHolder currently connected to an IOIO
+   * board?
    */
-  private boolean cycling;
+  private boolean connected;
+
+  private boolean constructing;
 
   private final int inPin;
   private final int outPin;
@@ -77,42 +78,30 @@ final class GlueIOIOPort extends IOIOPort implements IOIOConnectionListener {
     _holder.addListener(this);
   }
 
-  /**
-   * Wait for a certain amoutn of time until the port has been
-   * reconnected after a baud rate change.  Call this to avoid
-   * spurious I/O errors while the baud rate is being changed.
-   */
-  private synchronized void waitCycled() {
-    if (!cycling)
-      return;
-
-    /* wait only once */
-    cycling = false;
-
-    try {
-      wait(200);
-    } catch (InterruptedException e) {
-    }
-  }
-
   @Override public void onIOIOConnect(IOIO ioio)
     throws ConnectionLostException, InterruptedException {
-    connected = true;
 
-    Uart uart;
     try {
-      uart = ioio.openUart(inPin, outPin, baudrate, Uart.Parity.NONE,
-                           Uart.StopBits.ONE);
-    } catch (IllegalArgumentException e) {
-      Log.w(TAG, "IOIO.openUart() failed", e);
-      return;
-    }
+      synchronized(this) {
+        connected = true;
+        constructing = true;
+      }
 
-    set(uart);
+      Uart uart;
+      try {
+        uart = ioio.openUart(inPin, outPin, baudrate, Uart.Parity.NONE,
+                             Uart.StopBits.ONE);
+      } catch (IllegalArgumentException e) {
+        Log.w(TAG, "IOIO.openUart() failed", e);
+        return;
+      }
 
-    synchronized(this) {
-      cycling = false;
-      notifyAll();
+      set(uart);
+    } finally {
+      synchronized(this) {
+        constructing = false;
+        notifyAll();
+      }
     }
   }
 
@@ -134,7 +123,12 @@ final class GlueIOIOPort extends IOIOPort implements IOIOConnectionListener {
   }
 
   @Override public int getState() {
-    return connected
+    boolean ready;
+    synchronized(this) {
+      ready = connected && !constructing;
+    }
+
+    return ready
       ? super.getState()
       : STATE_LIMBO;
   }
@@ -152,15 +146,24 @@ final class GlueIOIOPort extends IOIOPort implements IOIOConnectionListener {
       /* this port was already closed */
       return false;
 
+    final boolean wasConnected = connected;
+
     baudrate = _baudrate;
-    if (connected)
-      cycling = true;
     holder.cycleListener(this);
+
+    if (wasConnected) {
+      try {
+        /* wait until the port has been reconnected after a baud rate
+           change; onIOIOConnect() will be called in another thread, and
+           any attempt to do I/O before onIOIOConnect() has finished is
+           doomed to fail */
+        synchronized(this) {
+          wait(200);
+        }
+      } catch (InterruptedException e) {
+      }
+    }
+
     return true;
   }
-
-  @Override public int write(byte[] data, int length) {
-    waitCycled();
-    return super.write(data, length);
-  }
 }
