@@ -25,13 +25,12 @@ Copyright_License {
 #define ABSTRACT_TASK_FACTORY_HPP
 
 #include "Util/NonCopyable.hpp"
-#include "Util/ConstArray.hpp"
 #include "Compiler.h"
 #include "Math/fixed.hpp"
 #include "TaskPointFactoryType.hpp"
 #include "ValidationError.hpp"
+#include "LegalPointSet.hpp"
 
-#include <vector>
 #include <stdint.h>
 
 struct TaskFactoryConstraints;
@@ -71,14 +70,6 @@ public:
     POINT_FINISH
   };
 
-  /** Vector of legal abstract point types (non-OZ specific) */
-  typedef std::vector<LegalAbstractPointType> LegalAbstractVector;
-
-  /** Vector of legal point types */
-  typedef std::vector<TaskPointFactoryType> LegalPointVector;
-
-  typedef ConstArray<TaskPointFactoryType> LegalPointConstArray;
-
 protected:
   const TaskFactoryConstraints &constraints;
 
@@ -88,14 +79,14 @@ protected:
   const TaskBehaviour &behaviour;
 
   /** list of valid start types, for specialisation */
-  LegalPointConstArray start_types;
+  const LegalPointSet start_types;
   /** list of valid intermediate types, for specialisation */
-  LegalPointConstArray intermediate_types;
+  const LegalPointSet intermediate_types;
   /** list of valid finish types, for specialisation */
-  LegalPointConstArray finish_types;
+  const LegalPointSet finish_types;
 
   /** list of errors returned by task validation */
-  TaskValidationErrorVector validation_errors;
+  TaskValidationErrorSet validation_errors;
 
 protected:
   /**
@@ -106,9 +97,9 @@ protected:
    */
   AbstractTaskFactory(const TaskFactoryConstraints &_constraints,
                       OrderedTask &_task, const TaskBehaviour &_behaviour,
-                      const LegalPointConstArray _start_types,
-                      const LegalPointConstArray _intermediate_types,
-                      const LegalPointConstArray _finish_types)
+                      const LegalPointSet &_start_types,
+                      const LegalPointSet &_intermediate_types,
+                      const LegalPointSet &_finish_types)
     :constraints(_constraints),
      task(_task), behaviour(_behaviour),
      start_types(_start_types),
@@ -233,7 +224,7 @@ public:
    *
    * @return list of valid start types
    */
-  const LegalPointConstArray &GetStartTypes() const {
+  const LegalPointSet &GetStartTypes() const {
     return start_types;
   }
 
@@ -242,7 +233,7 @@ public:
    *
    * @return list of valid intermediate types
    */
-  const LegalPointConstArray &GetIntermediateTypes() const {
+  const LegalPointSet &GetIntermediateTypes() const {
     return intermediate_types;
   }
 
@@ -251,7 +242,7 @@ public:
    *
    * @return list of valid finish types
    */
-  const LegalPointConstArray &GetFinishTypes() const {
+  const LegalPointSet &GetFinishTypes() const {
     return finish_types;
   }
 
@@ -450,6 +441,16 @@ public:
    */
   bool ValidateFAIOZs();
 
+  /**
+   * Checks whether shapes of all OZs, start, finish are valid
+   * for an MAT task
+   * Appends warning message to validation_errors
+   * This is used independently of check_task() validation
+   *
+   * @return True if all OZs are valid for a MAT
+   */
+  bool ValidateMATOZs();
+
   gcc_pure
   const OrderedTaskBehaviour &GetOrderedTaskBehaviour() const;
 
@@ -473,7 +474,7 @@ public:
    * @return Vector of valid types in position
    */
   gcc_pure
-  LegalPointVector GetValidIntermediateTypes(unsigned position) const;
+  LegalPointSet GetValidIntermediateTypes(unsigned position) const;
 
   /**
    * List all valid start types for the task type
@@ -481,7 +482,9 @@ public:
    * @return Vector of valid types in position
    */
   gcc_pure
-  LegalPointVector GetValidStartTypes() const;
+  const LegalPointSet &GetValidStartTypes() const {
+    return start_types;
+  }
 
   /**
    * Checks for a finish point.
@@ -497,7 +500,9 @@ public:
    * @return Vector of valid types in position
    */
   gcc_pure
-  LegalPointVector GetValidIntermediateTypes() const;
+  const LegalPointSet &GetValidIntermediateTypes() const {
+    return intermediate_types;
+  }
 
   /**
    * List all valid finish types for the task type
@@ -505,7 +510,9 @@ public:
    * @return Vector of valid types in position
    */
   gcc_pure
-  LegalPointVector GetValidFinishTypes() const;
+  const LegalPointSet &GetValidFinishTypes() const {
+    return finish_types;
+  }
 
   /**
    * List valid types for a given position
@@ -515,14 +522,15 @@ public:
    * @return Vector of valid types in position
    */
   gcc_pure
-  LegalPointVector GetValidTypes(unsigned position) const;
+  LegalPointSet GetValidTypes(unsigned position) const;
 
   /**
    * Inspect the type of a point
    *
    * @param point Point to check
    *
-   * @return Type of supplied point
+   * @return Type of supplied point based on the observation zone shape and
+   * TaskPoint type
    */
   gcc_pure
   TaskPointFactoryType GetType(const OrderedTaskPoint &point) const;
@@ -558,7 +566,9 @@ public:
    * @return True if type is valid
    */
   gcc_pure
-  bool IsValidFinishType(TaskPointFactoryType type) const;
+  bool IsValidFinishType(TaskPointFactoryType type) const {
+    return finish_types.Contains(type);
+  }
 
   /**
    * Determine if a type is valid for a StartPoint
@@ -568,7 +578,9 @@ public:
    * @return True if type is valid
    */
   gcc_pure
-  bool IsValidStartType(TaskPointFactoryType type) const;
+  bool IsValidStartType(TaskPointFactoryType type) const {
+    return start_types.Contains(type);
+  }
 
   /**
    * Determine if a type is valid for an IntermediateTaskPoint
@@ -578,7 +590,9 @@ public:
    * @return True if type is valid
    */
   gcc_pure
-  bool IsValidIntermediateType(TaskPointFactoryType type) const;
+  bool IsValidIntermediateType(TaskPointFactoryType type) const {
+    return intermediate_types.Contains(type);
+  }
 
   /**
    * removes excess turnpoints from end of task if the
@@ -605,7 +619,9 @@ public:
    * @return returns vector of errors for current task
    */
   gcc_pure
-  TaskValidationErrorVector GetValidationErrors();
+  const TaskValidationErrorSet &GetValidationErrors() const {
+    return validation_errors;
+  }
 
 protected:
   /**
@@ -657,9 +673,20 @@ protected:
    *
    * @param e The validation error type to be added
    */
-  void AddValidationError(TaskValidationErrorType e);
+  void AddValidationError(TaskValidationErrorType e) {
+    validation_errors.Add(e);
+  }
 
 private:
+  gcc_pure
+  TaskPointFactoryType GetDefaultStartType() const;
+
+  gcc_pure
+  TaskPointFactoryType GetDefaultIntermediateType() const;
+
+  gcc_pure
+  TaskPointFactoryType GetDefaultFinishType() const;
+
   /**
    * Verifies and sets the finish waypoint per the is_closed
    * property of task type.
@@ -674,7 +701,9 @@ private:
   /**
    * Clears the vector of validation errors for the current task
    */
-  void ClearValidationErrors();
+  void ClearValidationErrors() {
+    validation_errors = TaskValidationErrorSet();
+  }
 };
 
 #endif
